Backtracking line search for SDF collisions.

Increased tolerance above zero in nutbolt.xml since now the two parts lock otherwise. Measured speedup of 2x in this example.

This solves the issue of scale-dependent step sizes. Tested on gears with 10cm diameter and 2cm thickness.

PiperOrigin-RevId: 584009449
Change-Id: Ied2f62dbbbc592470b91cf910f3553802a57c752
This commit is contained in:
Alessio Quaglino
2023-11-20 06:31:45 -08:00
committed by Copybara-Service
parent dbf44fe2b4
commit 8ca51b5318
8 changed files with 44 additions and 13 deletions
+2 -2
View File
@@ -8,7 +8,7 @@
</plugin>
<plugin plugin="mujoco.sdf.bolt">
<instance name="bolt">
<config key="radius" value="0.26"/>
<config key="radius" value="0.255"/>
</instance>
</plugin>
</extension>
@@ -30,7 +30,7 @@
</mesh>
</asset>
<option sdf_iterations="15" sdf_initpoints="60"/>
<option sdf_iterations="10" sdf_initpoints="20"/>
<default>
<geom solref="0.01 1" solimp=".95 .99 .0001" friction="0.01"/>